class UnipagException(Exception):
    """
    Parent for all Unipag exceptions.
    """

    def __init__(self, msg=None, http_code=None, http_body=None,
                 json_body=None):
        super(UnipagException, self).__init__(msg)
        self.http_code = http_code
        self.http_body = http_body
        self.json_body = json_body


class ConnectionError(UnipagException):
    """
    Unable to connect to Unipag API.
    """


class APIError(UnipagException):
    """
    There was a problem with Unipag API.
    """


class Unauthorized(UnipagException):
    """
    You did not provide a valid API key.
    """


class BadRequest(UnipagException):
    """
    Some of request parameters passed to Unipag were invalid.
    """


class Forbidden(UnipagException):
    """
    Access denied.
    """


class NotFound(UnipagException):
    """
    Requested object does not exist in Unipag.
    """


class MethodNotAllowed(UnipagException):
    """
    Requested method is not allowed for this object.
    """


class InternalError(UnipagException):
    """
    Internal Unipag error.
    """


class BadGateway(UnipagException):
    """
    Unexpected error occurred while communicating with target payment gateway.
    """


class ServiceUnavailable(UnipagException):
    """
    There was a problem while trying to fulfill your request.
    """



#!/usr/bin/env python

import os
import unipag

try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup

os.environ['PYTHONDONTWRITEBYTECODE'] = '1'

packages = ['unipag']
requires = ['requests>=0.9']

setup(
    name='unipag',
    version=unipag.__version__,
    description='Unipag Client for Python',
    long_description=open('README.rst').read(),
    author='Denis Stebunov',
    author_email='support@unipag.com',
    url='https://github.com/unipag/unipag-python',
    packages=packages,
    install_requires=requires,
    license=open('LICENSE').read(),
    zip_safe=False,
    classifiers=(
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'Natural Language :: English',
        'License :: OSI Approved :: ISC License (ISCL)',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
    ),
)

del os.environ['PYTHONDONTWRITEBYTECODE']